@@ -1,4 +1,4 @@
-if [ ! -f /etc/colordiffrc ]
+if [ ! -e /etc/colordiffrc ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/colordiffrc /etc/colordiffrc
